@@ -2,7 +2,7 @@
 classes. Provides the base functionality within the fit() and transform() methods
 shared by most transformers, like checking that input is a df, the size, NA, etc.
 """
-from typing import List, Optional, Union
+from typing import Dict, Optional
 
 import pandas as pd
 from sklearn.base import BaseEstimator, TransformerMixin
@@ -23,6 +23,47 @@ class BaseNumericalTransformer(BaseEstimator, TransformerMixin):
     variable transformers, discretisers, math combination.
     """
 
+    def _select_variables_from_dict(
+        self, X: pd.DataFrame, user_dict_: Dict
+    ) -> pd.DataFrame:
+        """
+        Checks that input is a dataframe, checks that variables in the dictionary
+        entered by the user are of type numerical.
+
+        Parameters
+        ----------
+        X : Pandas DataFrame
+
+        user_dict_ : Dictionary. Default = None
+            Any dictionary allowed by the transformer and entered by user.
+
+        Raises
+        ------
+        TypeError
+            If the input is not a Pandas DataFrame or a numpy array
+            If any of the variables in the dictionary are not numerical
+        ValueError
+            If there are no numerical variables in the df or the df is empty
+            If the variable(s) contain null values
+
+        Returns
+        -------
+        X : Pandas DataFrame
+            The same dataframe entered as parameter
+        """
+        # check input dataframe
+        X = _is_dataframe(X)
+
+        # find or check for numerical variables
+        variables = [x for x in user_dict_.keys()]
+        self.variables_ = _find_or_check_numerical_variables(X, variables)
+
+        # check if dataset contains na or inf
+        _check_contains_na(X, self.variables_)
+        _check_contains_inf(X, self.variables_)
+
+        return X
+
     def fit(self, X: pd.DataFrame, y: Optional[pd.Series] = None) -> pd.DataFrame:
         """
         Checks that input is a dataframe, finds numerical variables, or alternatively
@@ -54,9 +95,7 @@ class BaseNumericalTransformer(BaseEstimator, TransformerMixin):
         X = _is_dataframe(X)
 
         # find or check for numerical variables
-        self.variables_: List[Union[str, int]] = _find_or_check_numerical_variables(
-            X, self.variables
-        )
+        self.variables_ = _find_or_check_numerical_variables(X, self.variables)
 
         # check if dataset contains na or inf
         _check_contains_na(X, self.variables_)
