@@ -1,16 +1,16 @@
-from typing import List, Union
 import warnings
+from typing import List, Union
 
 import pandas as pd
-from sklearn.ensemble import RandomForestClassifier
 from sklearn.model_selection import cross_validate
 
 from feature_engine.dataframe_checks import _is_dataframe
+from feature_engine.selection.base_selector import BaseSelector
+from feature_engine.validation import _return_tags
 from feature_engine.variable_manipulation import (
     _check_input_parameter_variables,
     _find_or_check_numerical_variables,
 )
-from feature_engine.selection.base_selector import BaseSelector
 
 Variables = Union[None, int, str, List[Union[str, int]]]
 
@@ -30,19 +30,19 @@ class SelectBySingleFeaturePerformance(BaseSelector):
 
     Parameters
     ----------
-    variables : str or list, default=None
+    estimator : object
+        A Scikit-learn estimator for regression or classification.
+
+    variables: str or list, default=None
         The list of variable(s) to be evaluated.
         If None, the transformer will evaluate all numerical variables in the dataset.
 
-    estimator : object, default = RandomForestClassifier()
-        A Scikit-learn estimator for regression or classification.
-
-    scoring : str, default='roc_auc'
+    scoring: str, default='roc_auc'
         Desired metric to optimise the performance for the estimator. Comes from
         sklearn.metrics. See the model evaluation documentation for more options:
         https://scikit-learn.org/stable/modules/model_evaluation.html
 
-    threshold : float, int, default = None
+    threshold: float, int, default = None
         The value that defines if a feature will be kept or removed.
 
         The r2varies between 0 and 1. So a threshold needs to be set-up within
@@ -57,8 +57,24 @@ class SelectBySingleFeaturePerformance(BaseSelector):
         The threshold can be specified by the user. If None, it will be automatically
         set to the mean performance value of all features.
 
-    cv : int, default=3
-        Desired number of cross-validation fold to be used to fit the estimator.
+    cv: int, cross-validation generator or an iterable, default=3
+        Determines the cross-validation splitting strategy. Possible inputs for cv are:
+
+            - None, to use cross_validate's default 5-fold cross validation
+
+            - int, to specify the number of folds in a (Stratified)KFold,
+
+            - CV splitter
+                - (https://scikit-learn.org/stable/glossary.html#term-CV-splitter)
+
+            - An iterable yielding (train, test) splits as arrays of indices.
+
+        For int/None inputs, if the estimator is a classifier and y is either binary or
+        multiclass, StratifiedKFold is used. In all other cases, Fold is used. These
+        splitters are instantiated with shuffle=False so the splits will be the same
+        across calls.
+
+        For more details check Scikit-learn's cross_validate documentation
 
     Attributes
     ----------
@@ -68,6 +84,12 @@ class SelectBySingleFeaturePerformance(BaseSelector):
     feature_performance_:
         Dictionary with the single feature model performance per feature.
 
+    variables_:
+        The variables to consider for the feature selection.
+
+    n_features_in_:
+        The number of features in the train set used in fit.
+
     Methods
     -------
     fit:
@@ -80,16 +102,13 @@ class SelectBySingleFeaturePerformance(BaseSelector):
 
     def __init__(
         self,
-        estimator=RandomForestClassifier(),
+        estimator,
         scoring: str = "roc_auc",
-        cv: int = 3,
+        cv=3,
         threshold: Union[int, float] = None,
         variables: Variables = None,
     ):
 
-        if not isinstance(cv, int) or cv < 1:
-            raise ValueError("cv can only take positive integers bigger than 1")
-
         if threshold:
             if not isinstance(threshold, (int, float)):
                 raise ValueError("threshold can only be integer, float or None")
@@ -119,10 +138,10 @@ class SelectBySingleFeaturePerformance(BaseSelector):
 
         Parameters
         ----------
-        X : pandas dataframe of shape = [n_samples, n_features]
+        X: pandas dataframe of shape = [n_samples, n_features]
            The input dataframe
 
-        y : array-like of shape (n_samples)
+        y: array-like of shape (n_samples)
            Target variable. Required to train the estimator.
 
         Returns
@@ -134,12 +153,12 @@ class SelectBySingleFeaturePerformance(BaseSelector):
         X = _is_dataframe(X)
 
         # find numerical variables or check variables entered by user
-        self.variables = _find_or_check_numerical_variables(X, self.variables)
+        self.variables_ = _find_or_check_numerical_variables(X, self.variables)
 
         self.feature_performance_ = {}
 
         # train a model for every feature and store the performance
-        for feature in self.variables:
+        for feature in self.variables_:
             model = cross_validate(
                 self.estimator,
                 X[feature].to_frame(),
@@ -161,13 +180,13 @@ class SelectBySingleFeaturePerformance(BaseSelector):
             f
             for f in self.feature_performance_.keys()
             if self.feature_performance_[f] < threshold
-            ]
+        ]
 
         # check we are not dropping all the columns in the df
         if len(self.features_to_drop_) == len(X.columns):
             warnings.warn("All features will be dropped, try changing the threshold.")
 
-        self.input_shape_ = X.shape
+        self.n_features_in_ = X.shape[1]
 
         return self
 
@@ -178,3 +197,12 @@ class SelectBySingleFeaturePerformance(BaseSelector):
         return X
 
     transform.__doc__ = BaseSelector.transform.__doc__
+
+    def _more_tags(self):
+        tags_dict = _return_tags()
+        # add additional test that fails
+        tags_dict["_xfail_checks"]["check_estimators_nan_inf"] = "transformer allows NA"
+        tags_dict["_xfail_checks"][
+            "check_parameters_default_constructible"
+        ] = "transformer has 1 mandatory parameter"
+        return tags_dict
